==> mingw-w64-clang-i686-liblas-1.8.1-2-any.pkg.tar.zst: clang32/lib/cmake/libLAS/liblas-depends-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "las" for configuration "Release"
set_property(TARGET las APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/liblas.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libtiff.dll.a;${_IMPORT_PREFIX}/lib/libgeotiff.dll.a;${_IMPORT_PREFIX}/lib/libboost_program_options-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_thread-mt.dll.a;-lpthread;${_IMPORT_PREFIX}/lib/libboost_system-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_iostreams-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_filesystem-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_chrono-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_atomic-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_regex-mt.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/liblas.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS las )
list(APPEND _IMPORT_CHECK_FILES_FOR_las "${_IMPORT_PREFIX}/lib/liblas.dll.a" "${_IMPORT_PREFIX}/bin/liblas.dll" )

# Import target "las_c" for configuration "Release"
set_property(TARGET las_c APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las_c PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/liblas_c.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "las"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/liblas_c.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS las_c )
list(APPEND _IMPORT_CHECK_FILES_FOR_las_c "${_IMPORT_PREFIX}/lib/liblas_c.dll.a" "${_IMPORT_PREFIX}/bin/liblas_c.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-i686-liblas-1.8.1-3-any.pkg.tar.zst: clang32/lib/cmake/libLAS/liblas-depends-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "las" for configuration "Release"
set_property(TARGET las APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/liblas.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libtiff.dll.a;${_IMPORT_PREFIX}/lib/libgeotiff.dll.a;${_IMPORT_PREFIX}/lib/libboost_program_options-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_thread-mt.dll.a;-lpthread;${_IMPORT_PREFIX}/lib/libboost_system-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_iostreams-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_filesystem-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_chrono-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_atomic-mt.dll.a;${_IMPORT_PREFIX}/lib/libboost_regex-mt.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/liblas.dll"
  )

list(APPEND _cmake_import_check_targets las )
list(APPEND _cmake_import_check_files_for_las "${_IMPORT_PREFIX}/lib/liblas.dll.a" "${_IMPORT_PREFIX}/bin/liblas.dll" )

# Import target "las_c" for configuration "Release"
set_property(TARGET las_c APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las_c PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/liblas_c.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "las"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/liblas_c.dll"
  )

list(APPEND _cmake_import_check_targets las_c )
list(APPEND _cmake_import_check_files_for_las_c "${_IMPORT_PREFIX}/lib/liblas_c.dll.a" "${_IMPORT_PREFIX}/bin/liblas_c.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
